/******************************************************************************
* C Include: Plate List                                                       *
*                                                                             *
* File:                                                                       *
*    platelst.h                                                               *
*                                                                             *
* History:                                                                    *
*    Created    : 15-JUN-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*          Sky Survey.                                                        *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Description:                                                                *
*    Include file for the Plate List functions.                               *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __PLATELST__
#define __PLATELST__

#include "generic.h"
#include "lnkd_lst.h"
#include "plate.h"

/***********************
* Plate List constants *
***********************/

#define PLATE_LIST_FILE         "DSS_PLTL"
#define DEFAULT_PLATE_LIST_FILE "lo_comp.lis"

/********************************
* Plate List derived data types *
*********************************/
typedef LL      PLATE_LIST; /* Linked list of plates           */
typedef LL_NODE PL_NODE   ; /* Node in a linked list of plates */

/***********************************
* Plate List functions' prototypes *
***********************************/
void       Add_Plate_to_List        (/* PLATE_LIST List                 ,
					PLATE      Plate                 */);

PLATE_LIST Create_Empty_Plate_List  (/* void                             */);

void       Delete_Plate_List        (/* PLATE_LIST List                  */);

void       Delete_Plate_List_Data   (/* PLATE_LIST List                  */);

PLATE      Find_Plate_in_List       (/* PLATE_LIST List                ,
				        STRING     Plate_Id             */);

STRING     Make_Plate_List_File_Name(/* STRING     Directory            */);

PLATE_LIST Read_Plate_List          (/* STRING     Plate_List_File_Name */);

#endif
